@@ -2,7 +2,7 @@ import os
 import sys
 from typing import List
 
-from typer import Typer, Option
+from typer import Typer, Option, Argument
 from rich.console import Console
 from rich.tree import Tree
 
@@ -19,7 +19,7 @@ err_console = Console(stderr=True, style="bold red")
 
 @app.command()
 def ls(
-    directory: str = os.getcwd(),
+    directory: str = Argument(os.getcwd()),
     include: List[str] = Option(
         [], "-i", "--include", help="list of regexes to include"
     ),
@@ -70,7 +70,7 @@ def ls(
 
 @app.command()
 def tree(
-    directory: str = os.getcwd(),
+    directory: str = Argument(os.getcwd()),
     include: List[str] = Option(
         [], "-i", "--include", help="list of regexes to include"
     ),
